#!/usr/bin/env python
# -*- cofing: utf-8 -*-
# vim:noet:sw=4:ts=4:ft=vim

'''
File: gpybit.py
Descrition: Simple but powerful GTK URL shortener
Author: Vladimir Kolev <admin@vladimirkolev.com>
'''

import gtk
import re
import pango
from pysqlite2 import dbapi2 as sqlite
from configobj import ConfigObj
config = ConfigObj("pybit.ini")
import shortlib

URL_CHECK = re.compile("([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}|(((http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+)(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#\\%]*[^]'\\.}>\\),\\\"]")


class PyApp(gtk.Window):
        def __init__(self):
                self.marker = 0
                super(PyApp, self).__init__()
                self.connect("delete-event", self.statact)
                self.set_size_request(450, 320)
                self.set_title("pyBit 3.0")
                self.set_icon_from_file("icons/pybit_icon.png")
                self.set_position(gtk.WIN_POS_CENTER)
                
                # Define the main VBox
                self.vbox = gtk.VBox()

                # Define the toolbar and add it to the VBox
                toolbar1 = gtk.Toolbar()
                tooltips = gtk.Tooltip()
                toolbar1.set_orientation(gtk.ORIENTATION_HORIZONTAL)
                toolbar1.set_style(gtk.TOOLBAR_ICONS)
                toolbar1.set_icon_size(gtk.ICON_SIZE_MENU)
                toolbar1.set_tooltips(True)
                self.vbox.pack_start(toolbar1, False, False)

                # Define the buttons in the toolbar
                twittw = gtk.Image()
                twittw.set_from_file("icons/twitt.png")
                twitt_button = gtk.ToolButton(twittw)
                twitt_button.set_label("Twitt")
                twitt_button.set_tooltip_text("Post to update site (twitter, identi.ca)")
                twitt_button.connect("clicked", self.post_to_update)
                toolbar1.insert(twitt_button, 0)
                
                toolbar1.insert(gtk.SeparatorToolItem(), 1)

                clearw = gtk.Image()
                clearw.set_from_file("icons/clear.png")
                clear_button = gtk.ToolButton(clearw)
                clear_button.set_label("Clear")
                clear_button.set_tooltip_text("Clear entries")
                clear_button.connect("clicked", self.clear_entries)
                toolbar1.insert(clear_button, 2)

                pastew = gtk.Image()
                pastew.set_from_file("icons/paste.png")
                paste_button = gtk.ToolButton(pastew)
                paste_button.set_label("Paste")
                paste_button.set_tooltip_text("Paste from clipboard")
                paste_button.connect("clicked", self.paste_from_clipboard)
                toolbar1.insert(paste_button, 3)

                prefw = gtk.Image()
                prefw.set_from_file("icons/preferences.png")
                pref_button = gtk.ToolButton(prefw)
                pref_button.set_label("Preferences")
                pref_button.set_tooltip_text("Open preferences dialog")
                pref_button.connect("clicked", self.edit_prefs)
                toolbar1.insert(pref_button, 4)
        
                dbw = gtk.Image()
                dbw.set_from_file("icons/database.png")
                db_button = gtk.ToolButton(dbw)
                db_button.set_label("Logs")
                db_button.set_tooltip_text("Show logs of your shortenings")
                db_button.connect("clicked", self.show_logs)
                toolbar1.insert(db_button, 5)
                toolbar1.insert(gtk.SeparatorToolItem(), 6)


                aboutw = gtk.Image()
                aboutw.set_from_file("icons/about.png")
                about_button = gtk.ToolButton(aboutw)
                about_button.set_label("About")
                about_button.set_tooltip_text("About gPyBit")
                about_button.connect("clicked", self.show_about_dialog)
                toolbar1.insert(about_button, 7)
                
                quitw = gtk.Image()
                quitw.set_from_file("icons/exit.png")
                quit_button = gtk.ToolButton(quitw)
                quit_button.set_label("Quit")
                quit_button.set_tooltip_text("Quit the application")
                quit_button.connect("clicked", self.quit_app)
                toolbar1.insert(quit_button, 8)
                                
                # The middle pyBit logo
                pybitlogo = gtk.Image()
                pybitlogo.set_from_file("icons/pybit-logo.png")
                self.vbox.pack_start(pybitlogo, False, False)

                # The frame for entering the long url
                # cntaining an gtk.Entry and gtk.Button
                hbox1 = gtk.HBox(spacing = 3)

                self.url_entry = gtk.Entry()
                self.url_entry.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse("blue"))
                fonturl = 'serif,monospace unicode 16'
                fonturl_desc = pango.FontDescription(fonturl)
                self.url_entry.modify_font(fonturl_desc)
                self.url_entry.connect("activate", self.on_short_url)

                short_button = gtk.Button()
                shortimg = gtk.Image()
                shortimg.set_from_file("icons/OK.png")
                short_button.set_image(shortimg)
                short_button.connect("clicked", self.on_short_url)
                
                hbox1.pack_start(self.url_entry, True, 5)
                hbox1.pack_start(short_button, False, 5)

                self.vbox.pack_start(hbox1, False), 5

                # The result entry with modified text font and size
                frame1 = gtk.Frame()
                frame1.set_label("Your short url:")
                self.result_entry = gtk.Entry()
                self.result_entry.set_editable(False)
                self.result_entry.set_alignment(0.5)
                self.result_entry.set_has_frame(False)
                self.result_entry.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse("black"))
                font = 'sans bold unicode 25'
                font_desc = pango.FontDescription(font)
                self.result_entry.modify_font(font_desc)
                frame1.add(self.result_entry)

                self.vbox.pack_start(frame1, False, 5)

                self.add(self.vbox)
        
                self.show_all()

                self.staticon = gtk.StatusIcon()
                self.staticon.set_from_file('icons/pybit_icon.png')
                self.staticon.set_tooltip_text("gPyBit Desktop URL Shortener")
                self.staticon.connect("activate", self.statact)
                self.staticon.connect("popup-menu", self.showMenu)

        def showMenu(self, status_icon, button, activate_time=1):
                """docstring for showMenu"""
                self.menu = gtk.Menu()
                self.quit = gtk.ImageMenuItem(gtk.STOCK_QUIT)
                self.quit.connect("activate", self.quit_app)
                self.about = gtk.ImageMenuItem(gtk.STOCK_ABOUT)
                self.about.connect("activate", self.show_about_dialog)
                self.showhide = gtk.ImageMenuItem("Show/Hide gPyBit")
                self.showhide.connect("activate", self.statact)
                self.prefers = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
                self.prefers.connect("activate", self.edit_prefs)
                self.men_separ = gtk.SeparatorMenuItem()
                self.menu.add(self.about)
                self.menu.add(self.showhide)
                self.menu.add(self.prefers)
                self.menu.add(self.men_separ)
                self.menu.add(self.quit)
                self.menu.show_all()
                self.menu.popup(None, None, gtk.status_icon_position_menu, button, activate_time, status_icon)

        def statact(self, widget, event=0):
                """docstring for statact"""
                if self.marker == 0:
                        self.hide_on_delete()
                        self.marker = 1
                        return True
                else:
                        self.show_all()
                        self.marker = 0

        def quit_app(self, widget):
                quitdiag = gtk.MessageDialog(self, gtk.DIALOG_DESTROY_WITH_PARENT, 
                                gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO,
                                "Are you sure to quit?")

                resp = quitdiag.run()

                if resp == gtk.RESPONSE_YES:
                        gtk.main_quit()
                
                quitdiag.destroy()


        def  show_about_dialog(self, widget):
                about_dialog = gtk.AboutDialog()
                about_dialog.set_destroy_with_parent (True)
                about_dialog.set_logo(gtk.gdk.pixbuf_new_from_file('icons/icon.png'))
                about_dialog.set_name('pyBit')
                about_dialog.set_version('3.0')
                about_dialog.set_copyright("(C) 2010 Vladimir Kolev")
                about_dialog.set_comments(("Simple desktop application for shortening URLs"))
                about_dialog.set_website('http://pybit.vladimirkolev.com')
                about_dialog.set_authors(['Vladimir kolev <vladi@vladimirkolev.com>'])
                about_dialog.run()
                about_dialog.destroy()

        def post_to_update(self, widget):
                updatedialog = gtk.Dialog(None, None, gtk.DIALOG_MODAL)
                updatedialog.set_title("pyBit Status update")
                updatedialog.set_resizable(False)
                updatedialog.set_size_request(300, 150)
                self.upbuff = gtk.TextBuffer()
                self.upbuff.connect('changed', self.text_count)
                uptext = gtk.TextView()
                uptext.set_wrap_mode(gtk.WRAP_WORD_CHAR)
                uptext.set_buffer(self.upbuff)
                updatedialog.vbox.pack_start(uptext, True)
                uphb = gtk.HBox()
                self.countlabel = gtk.Label()
                self.countlabel.set_justify(gtk.JUSTIFY_RIGHT)
                uphb.pack_end(self.countlabel, False)
                self.countlabel.set_markup("<b>140</b>")
                updatedialog.vbox.pack_end(uphb, False)

                updatedialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
                updatedialog.add_button(gtk.STOCK_EXECUTE, gtk.RESPONSE_ACCEPT)

                upbutt = gtk.Button(stock=gtk.STOCK_PASTE)
                upbutt.connect("clicked", self.on_status_paste)

                updatedialog.action_area.pack_end(upbutt)

                updatedialog.show_all()
                response = updatedialog.run()
                if response == gtk.RESPONSE_CLOSE:
                        updatedialog.destroy()
                elif response == gtk.RESPONSE_ACCEPT:
                        username = config['update_username']
                        password = config['update_password']
                        if self.upbuff.get_char_count() <= 140 and self.upbuff.get_char_count() > 1:
                                print "Updating your status at %s" % config['active_update_name']
                                print "With username: %s and password: %s" % (config['update_username'], config['update_password'])
                                print "Your status update: %s" % self.upbuff.get_text(self.upbuff.get_start_iter(), self.upbuff.get_end_iter())
                        elif self.upbuff.get_char_count() <= 0:
                                print "Not enough characters"
                        else:
                                print "Too much characters for updating your status!"
                        updatedialog.destroy()

        def on_status_paste(self, widget):
                self.upbuff.insert_at_cursor(self.result_entry.get_text())

        def text_count(self, buff):
                count = 140 - buff.get_char_count()
                if count >= 0:
                        self.countlabel.set_markup("<b>%s</b>" % count)
                else:
                        count = 0 - count
                        self.countlabel.set_markup("<span foreground=\"#FF0000\"><b>%s</b></span> chars too much!" % count)


        def clear_entries(self, widget):
                self.url_entry.set_text("")
                self.result_entry.set_text("")


        def edit_prefs(self, widget):
                prefdialog = gtk.Dialog(None, None, gtk.DIALOG_MODAL)
                prefdialog.set_title("pyBit Preferences")
                prefdialog.set_resizable(False)

                prefcomb = gtk.ComboBox()
                preflist = gtk.ListStore(gtk.gdk.Pixbuf, str)
                px = gtk.CellRendererPixbuf()
                text = gtk.CellRendererText()
                prefcomb.pack_start(px, False)
                prefcomb.pack_start(text, False)
                prefcomb.add_attribute(px, "pixbuf", 0)
                prefcomb.add_attribute(text, "text", 1)
                prefcomb.set_model(preflist)
                bitimg = gtk.gdk.pixbuf_new_from_file('icons/favs/bitly.png')
                preflist.append((bitimg, 'Bit.ly *'))
                isgdimg = gtk.gdk.pixbuf_new_from_file('icons/favs/isgd.png')
                preflist.append((isgdimg, 'Is.gd'))
                pingimg = gtk.gdk.pixbuf_new_from_file('icons/favs/ping.png')
                preflist.append((pingimg, 'Ping.fm *'))
                googlimg = gtk.gdk.pixbuf_new_from_file('icons/favs/googl.png')
                preflist.append((googlimg, 'Goo.gl'))
                cligsimg = gtk.gdk.pixbuf_new_from_file('icons/favs/cligs.png')
                preflist.append((cligsimg, 'Cli.gs *'))
                smshimg = gtk.gdk.pixbuf_new_from_file('icons/favs/smshme.png')
                preflist.append((smshimg, 'Smsh.me'))
                snipimg = gtk.gdk.pixbuf_new_from_file('icons/favs/snipurl.png')
                preflist.append((snipimg, 'Snipurl.com *'))
                ur1img = gtk.gdk.pixbuf_new_from_file('icons/favs/identica.png')
                preflist.append((ur1img, 'ur1.ca'))
                ur1bzimg = gtk.gdk.pixbuf_new_from_file('icons/favs/ur1.png')
                preflist.append((ur1bzimg, 'ur1.bz'))
                prefcomb.set_active(int(config['active_engine']))
                preflab1 = gtk.Label()
                preflab1.set_markup("<b>Short Engine:</b> (required)")
                prefhb1 = gtk.HBox()
                prefhb1.pack_start(preflab1)
                prefhb1.pack_start(prefcomb)

                preflb2 = gtk.Label()
                preflb2.set_markup("<b>Username:</b> (optional)")
                prefent1 = gtk.Entry()
                prefent1.set_text(config['engine_username'])
                prefhb2 = gtk.HBox()
                prefhb2.pack_start(preflb2)
                prefhb2.pack_start(prefent1)

                preflb3 = gtk.Label()
                preflb3.set_markup("<b>API Key:</b> (optional)    ")
                prefent2 = gtk.Entry()
                prefent2.set_text(config['engine_api_key'])
                prefhb3 = gtk.HBox()
                prefhb3.pack_start(preflb3)
                prefhb3.pack_start(prefent2)

                preflb4 = gtk.Label()
                preflb4.set_markup("<b>Status update site: </b>\t\t ")
                pref_update_comb = gtk.ComboBox()
                pref_update_list = gtk.ListStore(gtk.gdk.Pixbuf, str)
                pref_update_comb.pack_start(px, False)
                pref_update_comb.pack_start(text, False)
                pref_update_comb.add_attribute(px, "pixbuf", 0)
                pref_update_comb.add_attribute(text, "text", 1)
                pref_update_comb.set_model(pref_update_list)
                twitimg = gtk.gdk.pixbuf_new_from_file("icons/favs/twitter.png")
                pref_update_list.append((twitimg, "Twitter.com"))
                identimg = gtk.gdk.pixbuf_new_from_file("icons/favs/identica.png")
                pref_update_list.append((identimg, "Identi.ca"))
                pref_update_list.append((pingimg, "Ping.fm"))
                pref_update_comb.set_active(int(config['active_update']))
                prefhb4 = gtk.HBox()
                prefhb4.pack_start(preflb4)
                prefhb4.pack_start(pref_update_comb)

                preflb5 = gtk.Label()
                preflb5.set_markup("<b>Username:</b> (required)")
                prefent3 = gtk.Entry()
                prefent3.set_text(config['update_username'])
                prefhb5 = gtk.HBox()
                prefhb5.pack_start(preflb5)
                prefhb5.pack_start(prefent3)

                preflb6 = gtk.Label()
                preflb6.set_markup("<b>Password:</b> (required) ")
                prefent4 = gtk.Entry()
                prefent4.set_text(config['update_password'])
                prefent4.set_visibility(False)
                prefhb6 = gtk.HBox()
                prefhb6.pack_start(preflb6)
                prefhb6.pack_start(prefent4)

                prefsp = gtk.HSeparator()

                preflb7 = gtk.Label()
                preflb7.set_markup("<b>Enable/Disable url logging:</b>\t\t\t")
                prefcheck = gtk.CheckButton(None)
                prefcheck.set_active(int(config['keep_history']))
                prefhb7 = gtk.HBox()
                prefhb7.pack_start(preflb7)
                prefhb7.pack_start(prefcheck)
                

                prefdialog.vbox.pack_start(prefhb1)
                prefdialog.vbox.pack_start(prefhb2)
                prefdialog.vbox.pack_start(prefhb3)
                prefdialog.vbox.pack_start(prefsp)
                prefdialog.vbox.pack_start(prefhb4)
                prefdialog.vbox.pack_start(prefhb5)
                prefdialog.vbox.pack_start(prefhb6)
                prefdialog.vbox.pack_start(prefhb7)

                prefdialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CANCEL)
                prefdialog.add_button(gtk.STOCK_SAVE, gtk.RESPONSE_ACCEPT)

                #prefdialog.connect('response', self.on_prefs_response, prefcomb.get_active_text(), prefent1.get_text(), prefent2.get_text())

                prefdialog.show_all()
                response = prefdialog.run()
                if response == gtk.RESPONSE_CANCEL:
                        prefdialog.destroy()
                else:
                        #print "Engine to use: %s" % prefcomb.get_active()
                        #print "Engine string: %s" % self.get_active_text(prefcomb)
                        #print "Engine username: %s" % prefent1.get_text()
                        #print "Engine API Key: %s" % prefent2.get_text()
                        #print "Update site to use: %s" % pref_update_comb.get_active()
                        #print "Update site string: %s" % self.get_active_text(pref_update_comb)
                        #print "Update site username: %s" % prefent3.get_text()
                        #print "Update site password: %s" % prefent4.get_text()
                        #print "Keep track on URLs: %s" % int(prefcheck.get_active())
                        #print "--------------------------"
                        #print "** Saving your settings..."
                        config['active_engine'] = int(prefcomb.get_active())
                        config['active_engine_name'] = self.get_active_text(prefcomb)
                        config['engine_username'] = prefent1.get_text()
                        config['engine_api_key'] = prefent2.get_text().strip(" ")
                        config['active_update'] = int(pref_update_comb.get_active())
                        config['active_update_name'] = self.get_active_text(pref_update_comb)
                        config['update_username'] = prefent3.get_text()
                        config['update_password'] = prefent4.get_text().strip(" ")
                        config['keep_history'] = int(prefcheck.get_active())
                        try:
                                config.write()
                        except e:
                                self.show_errormsg("Problem writing your settings:\n%s" % e)
                        prefdialog.destroy()
        
        def get_active_text(self, combobox):
                model = combobox.get_model()
                active = combobox.get_active()
                if active < 0:
                        return None
                return model[active][1]

        def show_logs(self, widget):
                logdialog = gtk.Dialog()
                logdialog.set_size_request(600, 300)
                logdialog.set_title("URL logs")
                
                
                sw = gtk.ScrolledWindow()
                sw.set_shadow_type(gtk.SHADOW_ETCHED_IN)
                sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)

                logdialog.vbox.pack_start(sw, True, True, 0)

                store = self.create_model()

                self.treeView = gtk.TreeView(store)
                self.treeView.set_rules_hint(True)
                copybutt = gtk.Button(stock=gtk.STOCK_COPY)
                copybutt.connect('clicked', self.info_copy)
                sw.add(self.treeView)

                self.create_columns(self.treeView)

                logdialog.action_area.pack_start(copybutt)

                logdialog.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)

                logdialog.show_all()
                response = logdialog.run()
                if response == gtk.RESPONSE_CLOSE:
                        logdialog.destroy()
                logdialog.destroy()

        def info_copy(self, btn):
                selection = self.treeView.get_selection()
                model, itern = selection.get_selected()
                self.set_in_clipboard(model.get_value(itern, 1))



        def create_model(self):
                store = gtk.ListStore(str, str, str)

                try:
                        conn = sqlite.connect("urllog.db")
                except:
                        self.show_errormsg("Error:\nProblem connecting to the database")

                c = conn.cursor()
                try:
                        c.execute("""SELECT * FROM urllogs""")
                except:
                        self.show_errormsg("Error:\nProblem fetching the database")

                rows = c.fetchall()

                for row in rows:
                        store.append([row[0], row[1], row[2]])
                c.close()
                return store

        def create_columns(self, treeView):
                rendererText = gtk.CellRendererText()
                column = gtk.TreeViewColumn("ID", rendererText, text=0)
                column.set_sort_column_id(0)
                treeView.append_column(column)

                rendererText = gtk.CellRendererText()
                column = gtk.TreeViewColumn("Short", rendererText, text=1)
                column.set_sort_column_id(1)
                treeView.append_column(column)

                rendererText = gtk.CellRendererText()
                column = gtk.TreeViewColumn("Long", rendererText, text=2)
                column.set_sort_column_id(2)
                treeView.append_column(column)



        def paste_from_clipboard(self, widget):
                """docstring for paste_from_clipboard"""
                try:
                        clipboard = gtk.clipboard_get("CLIPBOARD")
                        if clipboard.wait_is_text_available() == True:
                                cliptext = clipboard.wait_for_text()
                                if re.match(URL_CHECK, cliptext):
                                        self.url_entry.set_text(cliptext)
                                else:
                                        self.show_errormsg("Not a valid URL");
                        else:
                                self.show_errormsg("Clipboard is empty")

                except e:
                        show_errormsg(e)

        def on_short_url(self, widget):
                long_url = self.url_entry.get_text()
                config.reload()
                if re.match(URL_CHECK, long_url):
                        #self.result_entry.set_text(self.url_entry.get_text())
                        if int(config['active_engine']) == 0:
                                short_url = shortlib.short_bitly(config['engine_username'], config['engine_api_key'], long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib Error with bit.ly")

                                elif not "http://" in short_url:
                                        self.show_errormsg("ERROR\n\n%s" % short_url)
                                else:
                                        self.set_in_clipboard(short_url)
                                        self.result_entry.set_text(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)

                        elif int(config['active_engine']) == 1:
                                short_url = shortlib.short_isgd(long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib Error!")
                                else:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)
                        elif int(config['active_engine']) == 2:
                                #short_url = shortlib.short_pingfm('241e0bb848efa6197bb7557049bff95a-1263514878', long_url)
                                #if short_url == 0:
                                #        self.show_errormsg("Shortlib Error with is.gd")
                                #else:
                                #        self.result_entry.set_text(short_url)
                                #        self.set_in_clipboard(short_url)
                                #        if int(config['keep_history']) == 1:
                                #                self.store_to_db(short_url, long_url)
                                self.show_errormsg("Ping.fm is currently disabled, since\npyBit doesn't have a public API Key")
                        elif int(config['active_engine']) == 3:
                                short_url = shortlib.short_googl(long_url)
                                if "http://" in short_url:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)

                                elif "Error" in short_url:
                                        self.show_errormsg(short_url)

                        elif int(config['active_engine']) == 4:
                                short_url = shortlib.short_cligs(config['engine_api_key'], long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib Error with cli.gs")
                                else:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)
                        elif int(config['active_engine']) == 5:
                                short_url = shortlib.short_smshme(long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib Error with smsh.me")
                                else:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)
                        elif int(config['active_engine']) == 6:
                                short_url = shortlib.short_snipurl(config['engine_username'], config['engine_api_key'], long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib Error with snipurl.com")
                                else:
                                        if 'http://sn.im' in short_url:
                                                self.result_entry.set_text(short_url)
                                                self.set_in_clipboard(short_url)
                                                if int(config['keep_history']) == 1:
                                                        self.store_to_db(short_url, long_url)
                                        else:
                                                self.show_errormsg(short_url)

                        elif int(config['active_engine']) == 7:
                                short_url = shortlib.short_ur1(long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib error with ur1.com")
                                else:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)

                        elif int(config['active_engine']) == 8:
                                short_url = shortlib.short_ur1bz(long_url)
                                if short_url == 0:
                                        self.show_errormsg("Shortlib error with ur1.bz")
                                elif "http://ur1.bz" in short_url:
                                        self.result_entry.set_text(short_url)
                                        self.set_in_clipboard(short_url)
                                        if int(config['keep_history']) == 1:
                                                self.store_to_db(short_url, long_url)
                                else:
                                        self.show_errormsg("ERROR:\n\n%s" % short_url)
                else:
                        self.show_errormsg("Please enter an URL to be shorted!")

        def store_to_db(self, short_url, long_url):
                conn = sqlite.connect("urllog.db")
                c = conn.cursor()
                try:
                        c.execute("""INSERT INTO urllogs(short, long) VALUES('%s', '%s')""" % (short_url, long_url))
                        conn.commit()
                        c.close()
                except e:
                        self.show_errormsg("Problem with the database:\n%s" % e)


        def set_in_clipboard(self, short_url):
                clipboard = gtk.clipboard_get("CLIPBOARD")
                clipboard.set_text(short_url)
                clipboard.store()

        def show_errormsg(self, short_url):
                msgerror = gtk.MessageDialog(self, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_ERROR,
                                             gtk.BUTTONS_CLOSE, "%s" % short_url)
                msgerror.run();
                msgerror.destroy();

if __name__ == '__main__':
        PyApp()
        gtk.main()
